# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 0.5.x   | :white_check_mark: |
| < 0.5   | :x:                |

## Reporting a Vulnerability

If you discover a security vulnerability, please report it responsibly:

1. **Do not** open a public GitHub issue
2. Email the maintainer at pagliara.gianluca@gmail.com
3. Include a description of the vulnerability and steps to reproduce

You should receive a response within 48 hours. If the vulnerability is confirmed, a fix will be developed and released as soon as possible.
